@@ -12,7 +12,7 @@ from ._internal import _config, _decorators, _typing_extra
 from ._internal import _dataclasses as _pydantic_dataclasses
 from ._migration import getattr_migration
 from .config import ConfigDict
-from .fields import Field
+from .fields import Field, FieldInfo
 
 if TYPE_CHECKING:
     from ._internal._dataclasses import PydanticDataclass
@@ -107,7 +107,7 @@ def dataclass(
     kw_only: bool = False,
     slots: bool = False,
 ) -> Callable[[type[_T]], type[PydanticDataclass]] | type[PydanticDataclass]:
-    """Usage docs: https://docs.pydantic.dev/2.4/concepts/dataclasses/
+    """Usage docs: https://docs.pydantic.dev/2.5/concepts/dataclasses/
 
     A decorator used to create a Pydantic-enhanced dataclass, similar to the standard Python `dataclass`,
     but with added validation.
@@ -143,9 +143,29 @@ def dataclass(
 
     if sys.version_info >= (3, 10):
         kwargs = dict(kw_only=kw_only, slots=slots)
+
+        def make_pydantic_fields_compatible(cls: type[Any]) -> None:
+            """Make sure that stdlib `dataclasses` understands `Field` kwargs like `kw_only`
+            To do that, we simply change
+              `x: int = pydantic.Field(..., kw_only=True)`
+            into
+              `x: int = dataclasses.field(default=pydantic.Field(..., kw_only=True), kw_only=True)`
+            """
+            for field_name in cls.__annotations__:
+                try:
+                    field_value = getattr(cls, field_name)
+                except AttributeError:
+                    # no default value has been set for this field
+                    continue
+                if isinstance(field_value, FieldInfo) and field_value.kw_only:
+                    setattr(cls, field_name, dataclasses.field(default=field_value, kw_only=True))
+
     else:
         kwargs = {}
 
+        def make_pydantic_fields_compatible(_) -> None:
+            return None
+
     def create_dataclass(cls: type[Any]) -> type[PydanticDataclass]:
         """Create a Pydantic dataclass from a regular dataclass.
 
@@ -185,6 +205,8 @@ def dataclass(
                 bases = bases + (generic_base,)
             cls = types.new_class(cls.__name__, bases)
 
+        make_pydantic_fields_compatible(cls)
+
         cls = dataclasses.dataclass(  # type: ignore[call-overload]
             cls,
             # the value of init here doesn't affect anything except that it makes it easier to generate a signature
